#!/usr/bin/env python

name="fastspell"

from .fastspell import FastSpell
